@@ -752,94 +752,6 @@ def project_set_up_locally(
         typer.echo("Public key copied to clipboard.")
 
 
-@app.command("build_and_run")
-def build_and_run(
-    dockerfile: str | None = typer.Argument(
-        None, help="Path to Dockerfile to build & run. If omitted, only lock & export requirements."
-    )
-):
-    """
-    - uv lock
-    - uv export --format requirements --no-dev --hashes > requirements.txt
-    - If DOCKERFILE argument is given: docker build -f DOCKERFILE . && docker run IMAGE
-    """
-
-    # ----- sanity checks for uv + project files -----
-    if shutil.which("uv") is None:
-        typer.secho("uv is not installed. Install it with: pip install uv", fg=typer.colors.RED)
-        raise typer.Exit(1)
-
-    if not pathlib.Path("pyproject.toml").exists():
-        typer.secho(f"pyproject.toml not found in {pathlib.Path.cwd()}", fg=typer.colors.RED)
-        raise typer.Exit(1)
-
-    # ----- 1) solve and lock -----
-    typer.secho("Running: uv lock", fg=typer.colors.BLUE)
-    p = subprocess.run(["uv", "lock"])
-    if p.returncode != 0:
-        typer.secho("uv lock failed.", fg=typer.colors.RED)
-        raise typer.Exit(p.returncode)
-
-    # ----- 2) export pinned, hashed requirements -----
-    typer.secho("Exporting hashed requirements to requirements.txt", fg=typer.colors.BLUE)
-    p = subprocess.run(
-        ["uv", "export", "--format", "requirements", "--no-dev", "--hashes"],
-        capture_output=True,
-        text=True,
-    )
-    if p.returncode != 0:
-        typer.secho("uv export failed:", fg=typer.colors.RED)
-        if p.stderr:
-            typer.echo(p.stderr.strip())
-        raise typer.Exit(p.returncode)
-
-    pathlib.Path("requirements.txt").write_text(p.stdout, encoding="utf-8")
-    typer.secho("requirements.txt written.", fg=typer.colors.GREEN)
-
-    # ----- 3) optional Docker build + run -----
-    if dockerfile is None:
-        typer.secho("No Dockerfile provided; skipping Docker build/run.", fg=typer.colors.BLUE)
-        return
-
-    df_path = pathlib.Path(dockerfile)
-    if not df_path.exists():
-        typer.secho(f"Dockerfile not found: {dockerfile}", fg=typer.colors.RED)
-        raise typer.Exit(1)
-
-    if shutil.which("docker") is None:
-        typer.secho("Docker CLI is not installed or not on PATH.", fg=typer.colors.RED)
-        raise typer.Exit(1)
-
-    # Image name: directory-name + '-img' (overridable via env IMAGE_NAME)
-    cwd_name = pathlib.Path.cwd().name
-    safe_name = re.sub(r"[^a-z0-9_.-]+", "-", cwd_name.lower())
-    image_name = os.environ.get("IMAGE_NAME", f"{safe_name}-img")
-
-    # Tag: short git sha if available, else timestamp (overridable via env TAG)
-    tag = os.environ.get("TAG")
-    if not tag:
-        try:
-            tag = subprocess.check_output(
-                ["git", "rev-parse", "--short", "HEAD"], text=True
-            ).strip()
-        except Exception:
-            tag = time.strftime("%Y%m%d%H%M%S")
-
-    image_ref = f"{image_name}:{tag}"
-
-    typer.secho(f"Building Docker image: {image_ref}", fg=typer.colors.BLUE)
-    build = subprocess.run(["docker", "build", "-f", str(df_path), "-t", image_ref, "."])
-    if build.returncode != 0:
-        typer.secho("docker build failed.", fg=typer.colors.RED)
-        raise typer.Exit(build.returncode)
-
-    typer.secho(f"Running container: {image_ref}", fg=typer.colors.BLUE)
-    try:
-        # interactive by default; relies on your ENTRYPOINT
-        subprocess.check_call(["docker", "run", "--rm", "-it", image_ref])
-    except subprocess.CalledProcessError as e:
-        typer.secho(f"docker run failed (exit {e.returncode}).", fg=typer.colors.RED)
-        raise typer.Exit(e.returncode)
 
 
 @app.command("copy-llm-instructions")
