@@ -3,7 +3,7 @@ import inspect
 import json
 import threading
 from concurrent.futures import Future
-
+from typing import Optional, List
 import pandas as pd
 
 import mainsequence.client as ms_client
@@ -131,6 +131,14 @@ class APIPersistManager:
             # Remove the future from the global registry once done.
             future_registry.remove_future(self._data_node_storage_future)
 
+
+    def get_last_observation(self,asset_list:Optional[List["Asset"]]):
+        unique_identifier_list=[]
+        if asset_list is not None:
+            unique_identifier_list=[a.unique_identifier for a in asset_list]
+        last_observation=self.data_node_storage.get_last_observation(unique_identifier_list=unique_identifier_list)
+        return last_observation
+
     def get_df_between_dates(self, *args, **kwargs) -> pd.DataFrame:
         """
         Retrieves a DataFrame from the API between specified dates.
@@ -575,6 +583,7 @@ class PersistManager:
         time_serie_source_code_git_hash: str,
         time_serie_source_code: str,
         build_configuration_json_schema: dict,
+            open_to_public:bool
     ) -> None:
         """
         Ensures local and remote persistence objects exist and sets their configurations.
@@ -605,6 +614,7 @@ class PersistManager:
                     data_source=data_source.model_dump(),
                     build_meta_data=remote_build_metadata,
                     build_configuration_json_schema=build_configuration_json_schema,
+                    open_to_public=open_to_public
                 )
 
                 dtd_metadata = DataNodeStorage.get_or_create(**kwargs)
@@ -736,6 +746,13 @@ class PersistManager:
             data_node_update=self.data_node_update, *args, **kwargs
         )
         return filtered_data
+    def get_last_observation(self,asset_list:Optional[List["Asset"]]):
+        unique_identifier_list=[]
+        if asset_list is not None:
+            unique_identifier_list=[a.unique_identifier for a in asset_list]
+        last_observation=self.data_node_storage.get_last_observation(unique_identifier_list=unique_identifier_list)
+        return last_observation
+
 
     def set_column_metadata(self, columns_metadata: list[ms_client.ColumnMetaData] | None) -> None:
         if self.data_node_storage:
@@ -800,7 +817,7 @@ class PersistManager:
 
             self._data_node_update_cached = self.data_node_update.upsert_data_into_table(
                 data=temp_df,
-                data_source=self.data_source,
+                data_source=self.data_source,overwrite=overwrite
             )
 
             persisted = True
