@@ -4,7 +4,6 @@ import os
 import sys
 from pathlib import Path
 
-from mainsequence.virtualfundbuilder.__main__ import get_pod_configuration
 
 from .utils import get_vfb_logger
 
@@ -50,7 +49,4 @@ if RUNS_IN_JOB:
     pass
 
 if runs_in_main_process():
-    if not os.environ.get("IGNORE_MS_AGENT","false").lower() == "true":
-        get_pod_configuration()
-    else:
-        logger.info("Ignoring MS agent registration")
\ No newline at end of file
+   pass
\ No newline at end of file
